unit loadform;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Buttons, IdBaseComponent, IdComponent,
  IdTCPConnection, IdTCPClient, IniFiles;

type
  TLoader = class(TForm)
    contbtn: TButton;
    LoadBtn: TButton;
    ExitBtn: TButton;
    OpDlg: TOpenDialog;
    SveBtn: TButton;
    SvDlg: TSaveDialog;
    FileList: TListBox;
    SpeedButton1: TSpeedButton;
    OpBtn: TButton;
    SpeedButton2: TSpeedButton;
    procedure contbtnClick(Sender: TObject);
    procedure LoadBtnClick(Sender: TObject);
    procedure ExitBtnClick(Sender: TObject);
    procedure SveBtnClick(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure FileListDblClick(Sender: TObject);
    procedure SpeedButton1Click(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure JvFormStorage1RestorePlacement(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure OpBtnClick(Sender: TObject);
    procedure SpeedButton2Click(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    Procedure LoadShip(Path: String);
    Procedure SaveShip(Path: String);
    Procedure NewShip;
  end;

var
  Loader:  TLoader;
  MainDir: String;

Const
  TLL_Error = 1;
  TLL_Info  = 0;
  TLL_Debug = 9;
  TLL_Fatal = 2;

  VER_GLON = 'Beta 4';

Procedure CallStart;

implementation
Uses Main, analysis, info, Generator, options, Logger;

{$R *.dfm}


Procedure CallStart;
Begin
  If OpForm.autoload_chk.Checked
  then Loader.LoadShip('Ship.ini') Else
  If MainForm.Showing then
  Begin
    MainForm.Close;
    AnaForm.Close;
    InfoForm.Close;
  End;
End;

Procedure TLoader.LoadShip(Path: String);
Begin
  MainForm.LoadShip(Path);
  MainForm.Show;
End;

Procedure TLoader.SaveShip(Path: String);
Begin
  MainForm.SaveShip(Path);
End;

Procedure TLoader.NewShip;
Begin
  LoadShip('cleanship.ini');
End;

procedure TLoader.contbtnClick(Sender: TObject);
begin
  Main.MainForm.Show;
  AnaForm.Show;
  InfoForm.Show;
end;

procedure TLoader.LoadBtnClick(Sender: TObject);
begin
  If not OpDlg.Execute then Exit;
  LoadShip(OpDlg.Filename);
end;

procedure TLoader.ExitBtnClick(Sender: TObject);
begin
  Loader.Close;
end;

procedure TLoader.SveBtnClick(Sender: TObject);
begin
  If not SvDlg.Execute then Exit;
  SaveShip(SvDlg.Filename);
end;

procedure TLoader.FormActivate(Sender: TObject);
var h: TSearchRec;
begin
  FileList.Items.Clear;
  If FindFirst('*.stsc',faAnyFile,h) <> 0 then Exit;
  FileList.Items.Add(h.Name);
  While FindNext(h) = 0 do
    FileList.Items.Add(h.Name);
end;

procedure TLoader.FileListDblClick(Sender: TObject);
begin
  If FIleLIst.ItemIndex < 0 then Exit;
  LoadShip(FileList.Items[FileList.ItemIndex]);
end;

procedure TLoader.SpeedButton1Click(Sender: TObject);
begin
  GenForm.Show;
end;

procedure TLoader.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  WriteLog('TLoader.FormClose', LT_debug, ET_NoErr, 'Last log line. Program shutting down, all done.');
end;

procedure TLoader.JvFormStorage1RestorePlacement(Sender: TObject);
begin
  CallStart;
end;

procedure TLoader.FormCreate(Sender: TObject);
Const
  PN = 'TLoader.FormCreate';

begin
  WriteLog(PN, LT_debug, ET_NoErr, 'Starting log now.');
  {Getting the directory structure set up}
  If not DirectoryExists('print') then
    Try
      MkDir('print');
    Except
      WriteLog(PN, LT_info, ET_IO, 'Could not create ''print'' dir, probably exists.');
    End;
  If not DirectoryExists('print\save') then
    Try
      MkDir('print\save');
    Except
      WriteLog(PN, LT_info, ET_IO, 'Could not create ''print\save'' dir, probably exists.');
    End;
  If not DirectoryExists('ops') then
    Try
      MkDir('ops')
    Except
      WriteLog(PN, LT_info, ET_IO, 'Could not create ''ops'' dir, probaly exists.');
    End;
  If not DirectoryExists('logs') then
    Try
      MkDir('logs')
    Except
      WriteLog(PN, LT_info, ET_IO, 'Could not create ''logs'' dir, probaly exists.');
    End;
  If FileExists('dev.txt') then
  Begin
    LogForm.Show;
    WriteLog(PN, LT_debug, ET_Internal, 'Going to debugger mode.');
  End;
  MainDir:= GetCurrentDir;
  WriteLog(PN, LT_debug, ET_Internal, MainDir);
end;

procedure TLoader.OpBtnClick(Sender: TObject);
begin
  OpForm.ShowModal;
end;

procedure TLoader.SpeedButton2Click(Sender: TObject);
begin
  LogForm.Show;
end;

end.
