unit print;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Buttons, ExtCtrls;

type
  TPrintForm = class(TForm)
    OutputSel: TRadioGroup;
    Label1: TLabel;
    SaveFileEdit: TEdit;
    SvPointSel: TSpeedButton;
    PrintBtn: TBitBtn;
    CancelBtn: TBitBtn;
    SvDlg: TSaveDialog;
    Label2: TLabel;
    StatLbl: TLabel;
    PrintMem: TMemo;
    procedure SvPointSelClick(Sender: TObject);
    procedure PrintBtnClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  PrintForm: TPrintForm;

implementation
Uses LoadForm, Main, Logger;

{$R *.dfm}

procedure TPrintForm.SvPointSelClick(Sender: TObject);
begin
  If not SvDlg.Execute then Exit;
  SaveFileEdit.Text:= SvDlg.Filename;
end;

Function GetStrPart(Init: String; Position: Byte; Sep: Char): String;
var x: Byte;
Begin
  If Position < 1 then Position:= 1;
  If (Position > 1) and (Position < 10) then
    For x:= 2 to Position do delete(init, 1, AnsiPos(Sep, Init))
  Else For x:= 2 to Trunc(Position / 10) do delete(init, 1, AnsiPos(Sep, Init));
  If Position < 10 then Delete(Init, AnsiPos(Sep, Init), Length(Init));
  For x:= 1 to Length(Init) do
    If Init[x] = '%' then Init[x]:= ' ';
  If Position < 10
  then Result:= EWS2S(Init)
  else Result:= Init;
End;

procedure TPrintForm.PrintBtnClick(Sender: TObject);
Const
  PN = 'PrintBtnClick';

Procedure CondPrint(Cond: TCheckBox; Text: String; Ind2: String; SUCost, PowerCost: TLabel);
var Line:  String;
    Index: Word;
Begin
  If Cond <> nil then
    If not Cond.Checked then Exit;
  Try
    Index:= StrToInt(Ind2);
  Except
    Index:= 0;
  End;
  Line:= Text;
  If Index <> 0 then Line:= Line + ' ('+IntToStr(Index)+')';
  Line:= Line + ': ';
  if SUCost <> nil then Line:= Line + SUCost.Caption;
  If PowerCost <> nil then Line:= Line + ', '+PowerCost.Caption;
  PrintMem.Lines.Add(Line);
End;

Procedure PrintList(List: TListBox; Text: String; Name, SU, Power, Effect: Byte);
var x,y:  Byte;
    Line: String;
    h:    String;

Begin
  If List.Items.Count < 2 then Exit;
  PrintMem.Lines.Add('');
  PrintMem.Lines.Add(' - ' + Text + ' (List) - ');
  For x:= 1 to List.Items.Count - 1 do
    With PrintMem.Lines do
    Begin
      h:= List.Items[x];
      Add(GetStrPart(h, Name, ' '));
      If SU <> 0 then Add('SU Cost: '+GetStrPart(h, SU, ' '));
      If Power <> 0 then Add('Power Cost: '+GetStrPart(h, Power, ' '));
      If Effect <> 0 then Add('Effect: '+GetStrPart(h, Effect, ' '));
      Add('');
    End;
  For y:= 1 to Length(Line) do
    If Line[y] = '%' then Line[y]:= ' ';
  PrintMem.Lines.Add('- End of listing -');
End;

begin
  StatLbl.Caption:= 'Error, please consult log';
  If OutputSel.ItemIndex = -1 then
  Begin
    WriteLog(PN, LT_Err, ET_UserIn, 'You must select a way to print.');
    Exit;
  End;
  If SaveFIleEdit.Text = '' then
  Begin
    WriteLog(PN, LT_Err, ET_UserIn, 'You must specify a file name.');
    Exit;
  End;
  StatLbl.Caption:= 'Working...';
  Case OutputSel.ItemIndex of
    0: Begin
         PrintMem.Lines.Clear;
         With mainForm, PrintMem.Lines do
         Begin
           {Writing the basic information}
           Add('STARSHIP SHEET');
           Add('===============');
           Add('');
           Add('BASIC INFORMATION');
           Add('=================');
           Add('');
           Add(basic_race_sel.text+' '+basic_class_sel.Text);
           Add('Name: '+gen_sname.Text);
           Add('Serial: '+gen_snr.Text);
           Add('Captain: '+gen_scap.Text);
           Add('');
           Add('Construction Agency: '+basic_agency_sel.text);
           Add('');
           Add('Size: '+basic_size_edit.Text);
           Add('');
           Add('');
           {Hull Systems}
           Add('HULL SYSTEMS');
           Add('============');
           Add('');
           Add('Outer Hull: '+suc_outerhull.Caption);
           CondPrint(hull_outerres_chk, ' -> Additional Resistance', hull_outerres_sel.Text,
                     suc_ort, nil);
           Add('Inner Hull: '+suc_innerhull.Caption);
           CondPrint(hull_innerres_chk, ' -> Additional Resistance', hull_innerres_sel.Text,
                     suc_irt, nil);
           Add('');
           CondPrint(hull_ablarmour_chk, 'Ablative Armour', hull_ablarmour_edit.Text, suc_aat, nil);
           CondPrint(hull_atmcap_chk, 'Atmospheric Capability', '', suc_atmcap, nil);
           CondPrint(hull_planetfall_chk, 'Planetfall Capability', '', suc_planetfall, nil);
           CondPrint(hull_ramming_chk, 'Ramming Hull', '', suc_ramming, nil);
           CondPrint(hull_energys_chk, 'Energy Sheath', '', suc_es, nil);
           CondPrint(hull_sensref_chk, 'Sensor Reflective', '', suc_sensref, nil);
           CondPrint(hull_borgregen_chk, 'Borg Regeneration', '', suc_borgregen, pwr_borgregen);
           CondPrint(hull_ssep_chk, 'Saucer Separation', '', suc_ssep, nil);
           CondPrint(hull_noattach_chk, ' -> No reattachment', '', nil, nil);
           CondPrint(hull_mvam_chk, 'Multi Vector Assault Mode', '', suc_mvam, nil);
           CondPrint(hull_dw_chk, 'Atmospheric Capability', hull_dw_edit.Text, suc_dw, nil);
           PrintList(hull_instsif_list, 'Structural Integrity Fields', 1, 2, 3, 4);
           {Personnel}
           Add('');
           Add('');
           Add('PERSONNEL SYSTEMS');
           Add('=================');
           Add('');
           Add('Housing');
           CondPrint(nil, 'Barracks', pers_barsize_edit.Text, suc_qbar, nil);
           CondPrint(nil, 'Spartan', pers_sparsize_edit.Text, suc_qspar, nil);
           CondPrint(nil, 'Basic', pers_bassize_edit.Text, suc_qbas, nil);
           CondPrint(nil, 'Expanded', pers_expsize_edit.Text, suc_qexp, nil);
           CondPrint(nil, 'Luxury', pers_luxsize_edit.Text, suc_qlux, nil);
           CondPrint(nil, 'Unusual', pers_unusize_edit.Text, suc_qunu, nil);
           Add('');
           CondPrint(pers_mls_chk, 'Main Life Support', pers_mls_edit.Text, suc_mls, pwr_mls);
           CondPrint(pers_rls_chk, 'Reserve Life Support', pers_rls_edit.Text, suc_rls, pwr_rls);
           CondPrint(pers_els_chk, 'Emergency Life Support', pers_els_edit.Text, suc_els, nil);
           CondPrint(pers_grav_chk, 'Gravity Systems', pers_grav_edit.Text, suc_grav, pwr_grav);
           CondPrint(pers_eat_chk, 'Emergency Life Support', pers_eat_edit.Text, suc_eat, nil);
           Add('');
           CondPrint(pers_fr_chk, 'Food Replicator System', pers_fr_edit.Text, suc_fr, pwr_fr);
           CondPrint(pers_nr_chk, 'Industrial Replicator Network', pers_nr_edit.Text, suc_nr, pwr_in);
           CondPrint(pers_br_chk, 'Big Industrial Replicators', pers_br_edit.Text, suc_br, pwr_br);
           Add('');
           CondPrint(pers_med_chk, 'Medical Station', pers_med_sel.Text, suc_med, pwr_med);
           CondPrint(pers_emh_chk, 'Emergency Medical Hologram', pers_emh_sel.Text, suc_emh, pwr_emh);
           CondPrint(pers_rec_chk, 'Recreational Aeras', pers_rec_sel.Text, suc_rec, pwr_rec);
           Add('');
           CondPrint(nil, 'Transportation System', pers_trans_sel.Text, suc_trans, pwr_trans);
           CondPrint(pers_fire_chk, 'Fire Suppression System', '', suc_fire, pwr_fire);
           CondPrint(pers_cargo_chk, 'Cargo Holds', pers_cargo_edit.Text, suc_cargo, nil);
           CondPrint(pers_esc_chk, 'Escape Pods', pers_esc_edit.Text, suc_escape, nil);
           CondPrint(pers_esc_chk, ' -> Pod Size Upgrade', '', suc_escupg, nil);
           Add('');
           CondPrint(pers_mss_chk, 'Main Science System', pers_mss_sel.Text, suc_science, nil);
           CondPrint(pers_labs_chk, 'Laboratories', pers_labs_edit.Text, suc_lab, nil);
           CondPrint(pers_slsk_chk, 'Specific Labs (Skill)', pers_slsk_edit.Text, suc_slsk, nil);
           CondPrint(pers_slsp_chk, 'Specific Labs (Specialisation)', pers_slsp_edit.Text, suc_slsp, nil);
           Add('');
           Add('');
           {Propulsion}
           Add('PROPULSION');
           Add('==========');
           Add('');
           PrintList(prop_instnac_list, 'Warp Nacelles (Cruising / Sustained / Maximum)', 1, 2, 0, 30);
           CondPrint(prop_coax_chk, 'Coaxial Drive', prop_coax_sel.Text, suc_coax, nil);
           CondPrint(prop_qsd_chk, 'Quantum Slipstream Drive', '', suc_qsd, pwr_qsd);
           CondPrint(prop_twd_chk, 'Transwarp Drive', '', suc_twd, pwr_twd);
           PrintList(prop_instimp_list, 'Impulse Engines (Sustained / Maximum / Power Production)',
                     1, 2, 0, 30);
           CondPrint(prop_rcs_chk, 'Reaction Control System', prop_rcs_edit.Text, suc_rcs, pwr_rcs);
           {Power}
           Add('');
           Add('');
           Add('POWER');
           Add('=====');
           PrintList(ener_instwarp_list, 'Warp Core Systems (Max Power / Specials)', 1, 2, 3, 40);
           CondPrint(ener_aux_chk, 'Auxiliary Power', ener_aux_edit.Text, suc_aux, nil);
           CondPrint(ener_emer_chk, 'Emergency Power', ener_emer_sel.Text, suc_emer, nil);
           CondPrint(nil, 'Electroplasma Systems', ener_aux_edit.Text, suc_eps, nil);
           CondPrint(ener_isomag_chk, ' -> Isomagnetoc ECP Conducts', '', suc_isomag, nil);
           CondPrint(ener_ep_chk, ' -> Extra Power', ener_ep_edit.Text, suc_ep, nil);
           {Operations}
           CondPrint(ops_mb_chk, 'Main Bridge', '', suc_mb, nil);
           CondPrint(ops_auxb_chk, 'Auxiliary Bridge', ops_auxb_edit.Text, suc_auxb, nil);
           Add('');
           CondPrint(ops_npc_chk, 'Computer Cores', ops_npc_edit.Text, suc_core, nil);
           CondPrint(ops_bpc_chk, 'Bioneural Computer Cores', ops_bpc_edit.Text, suc_bc, nil);
           CondPrint(ops_pcupg_chk, 'PC Uprating', ops_pcupg_sel.Text, suc_pcupg, nil);
           CondPrint(ops_odn_chk, 'Optical Data Network', ops_odn_edit.Text, suc_odn, nil);
           Add('');
           CondPrint(ops_nd_chk, 'Navigational Deflector', ops_nd_edit.Text, suc_nd, nil);
           CondPrint(ops_auxnd_chk, 'Auxiliary Nav. Deflector', ops_auxnd_edit.Text, suc_auxnd, nil);
           CondPrint(ops_auto_chk, 'Autopilot ('+ops_autoskill_sel.Text+':'+
                     ops_autoconc_sel.Text+')', ops_auto_edit.Text, suc_auto, nil);
           CondPrint(ops_nav_chk, 'Navigational Computer ('+ops_nav_sel.Text+')',
                     ops_nav_edit.Text, suc_fcsnav, nil);
           CondPrint(ops_idf_chk, 'Internal Dampening Field (IDF)', ops_idf_edit.Text, suc_idf, nil);
           CondPrint(ops_att_chk, 'Attitude Control', ops_att_edit.Text, suc_att, nil);
           Add('');
           CondPrint(ops_neuro_chk, 'Neurogenic Interface', '', suc_neuro, pwr_neuro);
           CondPrint(ops_msc_chk, 'Manual Steering Cloumn', '', suc_msc, pwr_msc);
           PrintList(ops_instcom_list, 'Communication Systems (Strength / Security)', 1, 2, 0, 30);
           CondPrint(ops_emcom_chk, 'Emergency Communications', '', suc_emcom, pwr_ecom);
           CondPrint(ops_holo_chk, 'Holographic Communications', '', suc_holo, nil);
           PrintList(ops_instcloak_list, 'Cloaking Devices', 1, 2, 3, 4);
           {Sensoric Data}
           Add('');
           Add('');
           Add('SENSORIC SYSTEMS');
           Add('================');
           PrintList(sens_instlr_list, 'Long Range Sensors (High / Low / Special)', 1, 2, 0, 30);
           PrintList(sens_instlat_list, 'Navigational Sensors (Strength / Gain / Coverage)', 1, 2, 0, 30);
           PrintList(sens_instnav_list, 'Lateral Sensors (Strength / Special)', 1, 2, 0, 30);
           PrintList(sens_instprobe_list, 'Probes (Speed / Range / Sensors)', 1, 0, 0, 20);
           {Tactical}
           Add('');
           Add('');
           Add('TACTICAL DATA');
           Add('=============');
           PrintList(tac_instbw_list, 'Beam Weapons (Dmg / Power / ROF / Special)', 1, 2, 4, 30);
           PrintList(tac_instst_list, 'TA / T / TS System', 1, 2, 3, 0);
           PrintList(tac_instmw_list, 'Missiles Weapons (Spread / Special)', 1, 2, 3, 40);
           PrintList(tac_instds_list, 'Deflector Shields (Protection / Special)', 1, 2, 0, 30);
           {Transport & Tracktor}
           Add('');
           Add('');
           Add('TRANSPORT & TRACKTOR');
           Add('====================');
           PrintList(trans_instt_list, 'Transporter (Beam) Systems', 1, 2, 3, 30);
         End;
       End;
    Else StatLbl.Caption:= 'Unknown format, aborted. Sorry.';
  End;
end;

end.
